﻿using UnityEngine;
using System.Collections;
using UnityEditor.iOS.Xcode9;
using System.IO;

/// <summary>
/// 目录操作
/// </summary>
public class XcodeDirectoryProcessor {

    /// <summary>
    /// 添加编译本地文件到Xcode工程
    /// </summary>
    /// <param name="pbxProject"></param>
    /// <param name="targetGuid"></param>
    /// <param name="copyDirectoryPath">源路径</param>
    /// <param name="buildPath">拷贝路径</param>
    /// <param name="currentDirectoryPath">拷贝路径/currentDirectoryPath</param>
    /// <param name="needToAddBuild"></param>
    public void CopyAndAddBuildToXcode(PBXProject pbxProject, string targetGuid, string copyDirectoryPath, string buildPath, string currentDirectoryPath, bool needToAddBuild = true){

		string unityDirectoryPath = copyDirectoryPath;
		string xcodeDirectoryPath = buildPath;
        Debug.Log("addFile:"+unityDirectoryPath+"/n"+xcodeDirectoryPath);
		if(!string.IsNullOrEmpty(currentDirectoryPath)){
			unityDirectoryPath = Path.Combine(unityDirectoryPath, currentDirectoryPath);
			xcodeDirectoryPath = Path.Combine(xcodeDirectoryPath, currentDirectoryPath);
			Delete (xcodeDirectoryPath);
			Directory.CreateDirectory(xcodeDirectoryPath);
		}
		foreach (string filePath in Directory.GetFiles(unityDirectoryPath)){
			string extension = Path.GetExtension (filePath);
			if(extension == ExtensionName.META){
				continue;
			}
			else if(extension == ExtensionName.ARCHIVE){
				pbxProject.AddBuildProperty(
					targetGuid, 
					"LIBRARY_SEARCH_PATHS", 
					"$(PROJECT_DIR)/" + currentDirectoryPath
				);
			}
			string fileName = Path.GetFileName (filePath);
			string copyPath = Path.Combine (xcodeDirectoryPath, fileName);
			if(fileName[0] == '.'){
				continue;
			}
			File.Delete(copyPath);
			File.Copy(filePath, copyPath);
			if(needToAddBuild){
				string relativePath = Path.Combine(currentDirectoryPath, fileName);
				pbxProject.AddFileToBuild(targetGuid, pbxProject.AddFile(relativePath, relativePath, PBXSourceTree.Source));
			}

		}
        //遍历文件夹
		foreach (string directoryPath in Directory.GetDirectories(unityDirectoryPath)){
			string directoryName = Path.GetFileName (directoryPath);
			bool nextNeedToAddBuild = needToAddBuild;
			if(directoryName.Contains(ExtensionName.FRAMEWORK) || directoryName.Contains(ExtensionName.BUNDLE) || 
			   directoryName == "Unity-iPhone"){
				nextNeedToAddBuild = false;
			}
			CopyAndAddBuildToXcode (
				pbxProject, targetGuid, 
				copyDirectoryPath, buildPath, Path.Combine(currentDirectoryPath, directoryName), 
				nextNeedToAddBuild
			);
			if(directoryName.Contains(ExtensionName.FRAMEWORK) || directoryName.Contains(ExtensionName.BUNDLE)){
				string relativePath = Path.Combine(currentDirectoryPath, directoryName);
				pbxProject.AddFileToBuild(targetGuid, pbxProject.AddFile(relativePath, relativePath, PBXSourceTree.Source));
				pbxProject.AddBuildProperty(
					targetGuid, 
					"FRAMEWORK_SEARCH_PATHS", 
					"$(PROJECT_DIR)/" + currentDirectoryPath
				);
			}
		}

	}

    /// <summary>
    /// 拷贝目录（拷贝时候会删除copyPath）
    /// </summary>
    /// <param name="sourcePath"></param>
    /// <param name="copyPath"></param>
	public void CopyAndReplace(string sourcePath, string copyPath)
	{
		Delete (copyPath);
		Directory.CreateDirectory(copyPath);
		foreach (var file in Directory.GetFiles(sourcePath)){
			File.Copy(file, Path.Combine(copyPath, Path.GetFileName(file)));
		}
		foreach (var dir in Directory.GetDirectories(sourcePath)){
			CopyAndReplace(dir, Path.Combine(copyPath, Path.GetFileName(dir)));
		}
	}
    /// <summary>
    /// 删除目录
    /// </summary>
    /// <param name="targetDirectoryPath"></param>
	public void Delete(string targetDirectoryPath){
		if (!Directory.Exists (targetDirectoryPath)) {
			return;
		}
		string[] filePaths = Directory.GetFiles(targetDirectoryPath);
		foreach (string filePath in filePaths){
			File.SetAttributes(filePath, FileAttributes.Normal);
			File.Delete(filePath);
		}
		string[] directoryPaths = Directory.GetDirectories(targetDirectoryPath);
		foreach (string directoryPath in directoryPaths){
			Delete(directoryPath);
		}
		Directory.Delete(targetDirectoryPath, false);
	}
}
